<?php
/**
 * @name Model_gesa
 * @description Classe modèle du plugin gesa 
 * @author Nicolas Biersart <n.biersart@esia-network.com>
 * @contributor
 * @copyright Nicolas Biersart 2014
 * @license
 * @esia 1.00
 * @version 1.00
 * @date 1/04/2014
 */
include_once GESA_CLASS;
class Model_gesa extends Model_esia
{
	public static function getGesaIDBySN($dbconnection,$sn){
                $query=$dbconnection->prepare("SELECT gesa_device_id FROM gesa_info WHERE gesa_sn=?");
                $query = parent::executeStatement($query,array($sn));
                if($row=$query->fetch(PDO::FETCH_OBJ)) return $row->gesa_device_id;
                return false;
        }

	/*@NAME InstanceGESA
	 *@IN: $dbconnection un objet PDO
	 *	$id = id ou nom du noeud 
	*@OUT: un objet gesa ou une classe fille
	*@TREAT: instancie un objet gesa.
	*@EXCEPTION: EsiaDbException si une erreur survient
	*/
	public static function getInstanceGESA($dbconnection,$id)
	{
		$dev = parent::InstanceNode($dbconnection,$id);
		$query=$dbconnection->prepare("SELECT gesa_device_id, gesa_max_slot, gesa_sn,gesa_version_base,gesa_version_nrpe,gesa_version_plugin,
											gesa_version_web,gesa_repo_global,gesa_repo_gesa,gesa_last_update,gesa_rsbp,gesa_local_ip,device_ip_address
									   FROM gesa_info 
									   JOIN esia_device ON device_id = gesa_device_id
									   WHERE gesa_device_id=?");
		$query = parent::executeStatement($query,array($dev->getId()));
		$gesa= new GESA();
		$gesa->constructDevice($dev);
		if($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$gesa->setSerialNumber($row->gesa_sn);
			$gesa->setMaxSlot($row->gesa_max_slot);
			$gesa->setVersionBase($row->gesa_version_base);
			$gesa->setVersionNRPE($row->gesa_version_nrpe);
			$gesa->setVersionPlugins($row->gesa_version_plugin);
			$gesa->setVersionWeb($row->gesa_version_web);
			$gesa->setRepositoryGlobal($row->gesa_repo_global);
			$gesa->setRepositoryGESA($row->gesa_repo_gesa);
			$gesa->setLastUpdate($row->gesa_last_update);
			$gesa->setMotherBoard($row->gesa_rsbp);
			$gesa->setLocalIPaddress($row->gesa_local_ip);
			$gesa->setPublicIPaddress($row->device_ip_address);
		}
		return $gesa;
	}
	/*@NAME count_service_execute
	 *@IN: $dbconnection un objet PDO
	 *	$id = id de la gesa 
	*@OUT: le nombre de service executé
	*@TREAT: compte le nombre de service lié à la GESA
	*@EXCEPTION: EsiaDbException si une erreur survient
	*/
	public static function count_service_execute($dbconnection,$id)
	{
		$query=$dbconnection->prepare("SELECT COUNT(*) AS nbr
						FROM esia_services
						JOIN esia_device ON device_id = service_device_id
						JOIN gesa_connected ON device_id = connected_device_id
						WHERE connected_gesa_id = ?");
		$query = parent::executeStatement($query,array($id));
		$row=$query->fetch(PDO::FETCH_OBJ);
		return $row->nbr;
	}
	/*@NAME getNodeLink
	 *@IN: $dbconnection un objet PDO
	 *	$id = id de la gesa 
	*@OUT: le nombre de service executé
	*@TREAT: compte le nombre de service lié à la GESA
	*@EXCEPTION: EsiaDbException si une erreur survient
	*/
	public static function getNodeLink($dbconnection,$id,$mode=null)
	{
		$query=$dbconnection->prepare("SELECT device_id,device_name,device_type
						FROM  esia_device
						JOIN gesa_connected ON device_id = connected_device_id
						WHERE connected_gesa_id = ?");
		$query = parent::executeStatement($query,array($id));
		$devices = array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			if($mode==Model_esia::NODE_INSTANCE)
			{
				$devices[]=parent::InstanceNode($dbconnection,$row->device_id);
			}
			else
			{
				$devices[]=array('id'=>$row->device_id,'name'=>$row->device_name,'type'=>$row->device_type);
			}
		}
		return $devices;
	}
	/*@NAME addGESA
	 *@IN: $dbconnection un objet PDO
	 *	$id identifiant de la gesa 
	*	$maxSlot nombre maximun de slot
	*	$sn numéro de série
	*@OUT:  *
	*@TREAT: ajoute une GESA à l'application
	*@EXCEPTION: EsiaDbException si une erreur survient
	*/
	public static function addGESA($dbconnection,$id,$maxSlot,$sn)
	{
		$serial_number=$sn;
		if(preg_match('#([0-9]{8})\-([0-9]{2})\-([0-9]*)#', $sn, $regs))
		{
			$serial_number=$regs[1].$regs[2].$regs[3];
		}
		$query=$dbconnection->prepare("INSERT INTO gesa_info(gesa_device_id, gesa_max_slot, gesa_sn) VALUES (:id, :max, :sn);");
		$query = parent::executeStatement($query,array(':id'=>$id,':max'=>$maxSlot,':sn'=>$serial_number));	

	}
	/*@NAME addGESA
	 *@IN: $dbconnection un objet PDO
	 *	$id identifiant de la gesa 
	*	$maxSlot nombre maximun de slot
	*	$sn numéro de série
	*@OUT:  *
	*@TREAT: ajoute une GESA à l'application
	*@EXCEPTION: EsiaDbException si une erreur survient
	*/
	public static function deleteGESA($dbconnection,$id)
	{
		$query = $dbconnection->prepare("DELETE FROM esia_device WHERE device_id =?;");
		$query = parent::executeStatement($query,array($nodeid));

	}
	
	public static function getIpGesa($dbconnection,$sn)
	{
		$query = $dbconnection->prepare("SELECT device_ip_address
										FROM esia_device
										JOIN gesa_info ON gesa_device_id = device_id
										WHERE gesa_sn = ?;");
		$query = parent::executeStatement($query,array($sn));
		if($row=$query->fetch(PDO::FETCH_OBJ)) return $row->device_ip_address;
	}

}
?>
